import { Component, OnInit } from "@angular/core";

@Component({
    selector: "core-email-admin",
    templateUrl: "core-email-admin.component.html",
    styleUrls: ["core-email-admin.component.css"],
})
export class CoreEmailAdminComponent implements OnInit {
    ngOnInit() {}
}
